==> org-lsst-ccs-subsystem-ocsbridge-2.5.0-sources.jar: org/lsst/ccs/subsystem/ocsbridge/DictionaryProvider.java <==
package org.lsst.ccs.subsystem.ocsbridge;

import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.bus.data.DataProviderDictionary;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.framework.HasLifecycle;
import org.lsst.ccs.services.DataProviderDictionaryService;
import org.lsst.ccs.services.DataProviderDictionaryService.DataProviderDictionaryEvent.EventType;
import org.lsst.ccs.services.DataProviderDictionaryService.DataProviderDictionaryListener;
import org.lsst.ccs.subsystem.ocsbridge.xml.Mapping;
import org.lsst.ccs.subsystem.ocsbridge.xml.SALClassDescription;
import org.lsst.ccs.subsystem.ocsbridge.xml.SALClassDescriptionMaker;

/**
 *
 * @author tonyj
 */
public class DictionaryProvider implements HasLifecycle {

    private static final Logger LOG = Logger.getLogger(DictionaryProvider.class.getName());

    @LookupField(strategy = LookupField.Strategy.TREE)
    private DataProviderDictionaryService dpdService;

    private final Listener listener = new Listener();
    private final Map<String, SALClassDescription> salClassDescriptions = new HashMap<>();

    @Override
    public void start() {
        dpdService.addDataProviderDictionaryListener(listener);
    }

    Map<String, SALClassDescription> getStatusClassDescriptions() {
        return salClassDescriptions;
    }

    private class Listener implements DataProviderDictionaryListener {

        Mapping mapping = Mapping.defaultMapping();
        
        @Override
        public void dataProviderDictionaryUpdate(DataProviderDictionaryService.DataProviderDictionaryEvent evt) {
            try {
                if (evt.getEventType() == EventType.ADDED) {
                    AgentInfo.AgentType type = evt.getAgentInfo().getType();
                    if (type == AgentInfo.AgentType.WORKER || type == AgentInfo.AgentType.SERVICE) {
                        String name = evt.getAgentInfo().getName();
                        DataProviderDictionary dictionary = evt.getDictionary();
                        SALClassDescriptionMaker maker = new SALClassDescriptionMaker(dictionary, "CCCamera", name, 1, mapping, "MONITORING", "trending");
                        salClassDescriptions.putAll(maker.getSALClassDescriptions());
                        LOG.log(Level.INFO, "Added dictionary for {0}", name);
                    }
                }
            } catch (Throwable t) {
                LOG.log(Level.SEVERE, "Exception adding dictionary", t);
            }
        }
    }
}

==> org-lsst-ccs-subsystem-ocsbridge-2.6.0-sources.jar: org/lsst/ccs/subsystem/ocsbridge/DictionaryProvider.java <==
package org.lsst.ccs.subsystem.ocsbridge;

import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.bus.data.DataProviderDictionary;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.framework.HasLifecycle;
import org.lsst.ccs.services.DataProviderDictionaryService;
import org.lsst.ccs.services.DataProviderDictionaryService.DataProviderDictionaryEvent.EventType;
import org.lsst.ccs.services.DataProviderDictionaryService.DataProviderDictionaryListener;
import org.lsst.ccs.subsystem.ocsbridge.xml.Mapping;
import org.lsst.ccs.subsystem.ocsbridge.xml.SALClassDescription;
import org.lsst.ccs.subsystem.ocsbridge.xml.SALClassDescriptionMaker;

/**
 * DictioanaryProvider is placed on the tree in the OCSBridge groovy file.
 * Its purpose is to listen for dictionaries published on the buses and keep a list of them which 
 * are used for converting telemetry and configuration (aka settings applied) to be sent to the 
 * OCS.
 * @author tonyj
 */
public class DictionaryProvider implements HasLifecycle {

    private static final Logger LOG = Logger.getLogger(DictionaryProvider.class.getName());

    @LookupField(strategy = LookupField.Strategy.TREE)
    private DataProviderDictionaryService dpdService;
    
    @LookupField(strategy = LookupField.Strategy.TREE)
    private OCSBridgeConfig config;

    private final Listener listener = new Listener();
    private final Map<String, SALClassDescription> salClassDescriptions = new HashMap<>();

    @Override
    public void start() {
        dpdService.addDataProviderDictionaryListener(listener);
    }

    Map<String, SALClassDescription> getStatusClassDescriptions() {
        return salClassDescriptions;
    }

    private class Listener implements DataProviderDictionaryListener {

        Mapping mapping = Mapping.defaultMapping();
        
        @Override
        public void dataProviderDictionaryUpdate(DataProviderDictionaryService.DataProviderDictionaryEvent evt) {
            try {
                if (evt.getEventType() == EventType.ADDED) {
                    AgentInfo.AgentType type = evt.getAgentInfo().getType();
                    if (type == AgentInfo.AgentType.WORKER || type == AgentInfo.AgentType.SERVICE) {
                        String name = evt.getAgentInfo().getName();
                        DataProviderDictionary dictionary = evt.getDictionary();
                        final int levelForAgent = getLevelForAgent(name);
                        SALClassDescriptionMaker maker = new SALClassDescriptionMaker(dictionary, config.getCSCRoot(), name, levelForAgent, mapping, "MONITORING", "trending");
                        salClassDescriptions.putAll(maker.getSALClassDescriptions());
                        LOG.log(Level.INFO, "Added dictionary for {0} at level {1}", new Object[]{name, levelForAgent});
                    }
                }
            } catch (Throwable t) {
                LOG.log(Level.SEVERE, "Exception adding dictionary", t);
            }
        }

        private int getLevelForAgent(String name) {
            if (name.equals("ats")) {
                return 0;
            } else if (name.equals("ats-power")) {
                return 0;
            }
            return 1;
        }
    }
}
